=======
History
=======

0.1.0 (2020-08-28)
------------------

* Add EasyAPI class that functions as a Blueprint
  for a set of api call routes.

   * Implement EasyAPI.route(.) decorator.

* Add a example/test Flask hello world greeting app.

   * Add tests for EasyAPI using the greet app.

* Add and update documentation.
* Refactoring and linting changes.
* Fix typos.

0.0.6 (2020-08-21)
------------------

* Fix project url in setup.py

0.0.5 (2020-08-20)
------------------

* Improve CD process.

0.0.4 (2020-08-19)
------------------

* Improve CD process.

0.0.3 (2020-08-19)
------------------

* Various changes to CI configuration.
* Update dependencies.
* Edit README.rst to add badges and alt-text.

0.0.2 (2020-08-19)
------------------

* Fix badges in readme
* Add pyup configuration

0.0.1 (2020-08-19)
------------------

* Fix minor issues and typos to make tests pass.

0.0.0 (2020-08-19)
------------------

* First release on PyPI. [Falied]
